@@ -33,8 +33,8 @@ class CANTOR_EXPORT LatexRenderer : public QObject
   public:
     enum Method{ LatexMethod = 0, MmlMethod = 1};
     enum EquationType{ InlineEquation = 0, FullEquation = 1};
-    LatexRenderer( QObject* parent = 0);
-    ~LatexRenderer();
+    LatexRenderer( QObject* parent = nullptr);
+    ~LatexRenderer() override;
 
     QString latexCode() const;
     void setLatexCode(const QString& src);
